@@ -16,15 +16,15 @@ nlp_bionlp13cg = en_ner_bionlp13cg_md.load()
 def disease_content(dailyMedURL, disease, header = False):
   """Extract subsection for a particular disease from a drug's DailyMed 'INDICATIONS AND USAGE' section.
 
-  Parse the url link using lxml library. Locate the subsection that disucsses the disease in 'INDICATIONS AND USAGE' section from the html's tree structure. 
-  If header is set to False, only the text content will be extracted. If header is set to True, the whole subsection including the subheading and its text content will be extracted.
+  Parse the URL link using the lxml library. Locate the subsection that discusses the disease in the 'INDICATIONS AND USAGE' section from the HTML's tree structure. 
+  If the header argument is set to False, only the text content will be extracted. If the header argument is set to True, the whole subsection including the subheading and its text content will be extracted.
 
   Parameters
   ----------
   dailyMedURL : str
       An URL link to a drug's DailyMed information page and quoted ("") as a string.
   disease : str
-      The name of a disease whose text information will be extract from 'INDICATIONS AND USAGE' section.
+      The name of a disease whose text information will be extracted from the 'INDICATIONS AND USAGE' section.
   header : bool, optional
       Extract the subheading, by default False. 
       If True, the subheading will be extracted. 
@@ -63,7 +63,7 @@ def disease_content(dailyMedURL, disease, header = False):
   dailyMedRp = requests.get(dailyMedURL)
   dailyMedPage = lxml.html.fromstring(dailyMedRp.text)
 
-  # locate 'INDICATIONS AND USAGE' section in DailyMed and extract the text content by certain cancer type. 
+  # locate the 'INDICATIONS AND USAGE' section in DailyMed and extract the text content by certain cancer type. 
   usagePath = "//li[a[contains(text(),'INDICATIONS AND USAGE')]]/div/div[h2[contains(translate(text(),'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'" + disease.lower() + "')]]"
   dailyMedDisContent = dailyMedPage.xpath(usagePath)
 
@@ -88,13 +88,12 @@ def disease_content(dailyMedURL, disease, header = False):
 def section_content(dailyMedURL, section):
   """Extract a whole section text content from the drug's DailyMed information page excluding the section heading.
 
-  Parse the url link using lxml library. Locate the section using the section's heading from the html's tree structure. Extract the text content of the section excluding the heading.
+  Parse the URL link using the lxml library. Locate the section using the section's heading from the HTML's tree structure. Extract the text content of the section excluding the heading.
 
   Parameters
   ----------
   dailyMedURL : str
-      An URL link to a drug DailyMed information page
-      and quoted ("") as a string.
+      An URL link to a drug DailyMed information page and quoted ("") as a string.
   section : str
       The header of the section.
 
@@ -151,7 +150,7 @@ def section_content(dailyMedURL, section):
 def drug_brand_label(dailyMedURL):
   """Extract drug label at the drug dailyMed label information page.
 
-  Parse the url link using lxml library. Locate and extract the drug label from the html's tree structure. 
+  Parse the URL link using the lxml library. Locate and extract the drug label from the HTML's tree structure. 
 
   Parameters
   ----------
@@ -163,7 +162,7 @@ def drug_brand_label(dailyMedURL):
   -------
   str
       Return drug label. 
-      If no drug label is found, return a zero length string (""). 
+      If no drug label is found, return a zero-length string (""). 
 
   Examples
   --------
@@ -197,7 +196,7 @@ def drug_brand_label(dailyMedURL):
 def ndc_code(dailyMedURL):
   """Extract NDC code(s) from the drug dailyMed label information page.
 
-  Parse the url link using lxml library. Locate and extract the NDC codes from the html's tree structure. It returns all the codes found in a string. The codes are seperated by comma. 
+  Parse the URL link using the lxml library. Locate and extract the NDC codes from the HTML's tree structure. It returns all the codes found in a string. The codes are separated by commas. 
 
   Parameters
   ----------
@@ -208,8 +207,7 @@ def ndc_code(dailyMedURL):
   Returns
   -------
   str
-      Return NDC codes(s) in a string. If more than one codes are found,
-      seperate by comma. 
+      Return NDC codes(s) in a string. If more than one code is found, codes are separated by commas. 
   
   Examples
   --------
@@ -258,7 +256,7 @@ def ndc_code(dailyMedURL):
 def gene_protein_chemical(text, gene= 1, protein = 1, chemical = 1):
   """Extract gene, protein, and drug labels from a string.
 
-  The function uses three pre-trained NER models from scispacy. Please see: https://allenai.github.io/scispacy/. We use en_ner_craft_md model to recognize genes. Entities labeled with "GGP" in this model are categorized as genes. We use en_ner_jnlpba_md model to recognize proteins. Entities labeled with "PROTEIN" in this model are categorized as proteins. We use en_ner_bionlp13cg_md model to recognize drugs. Entities labeled with "SIMPLE_CHEMICAL" in this model are categorized as drugs.
+  The function uses three pre-trained NER models from scispacy. Please see https://allenai.github.io/scispacy/. We use en_ner_craft_md model to recognize genes. Entities labeled with "GGP" in this model are categorized as genes. We use the en_ner_jnlpba_md model to recognize proteins. Entities labeled with "PROTEIN" in this model are categorized as proteins. We use en_ner_bionlp13cg_md model to recognize drugs. Entities labeled with "SIMPLE_CHEMICAL" in this model are categorized as drugs.
 
   Parameters
   ----------
@@ -278,11 +276,11 @@ def gene_protein_chemical(text, gene= 1, protein = 1, chemical = 1):
   -------
   dic
       Return a dictionary in which "gene", "proteins", or/and "chemical" are
-      the keys, lists of genes, proteins, or/and chemical are the values.
+      the keys, lists of genes, proteins, or/and chemicals are the values.
   
   Examples
   --------
-  Install the necessary packages and pri-trained models
+  Install the necessary packages and pre-trained models
   
   >>> # If using Colab Notebook, use !pip
   $ pip install scispacy
@@ -352,9 +350,9 @@ def gene_protein_chemical(text, gene= 1, protein = 1, chemical = 1):
 
 
 def sent_subtree(text):
-  """Extract the subtree of the patterns 'in conbination with' and 'used with' based on dependency parsing. 
+  """Extract the subtree of the patterns 'in combination with' and 'used with' based on dependency parsing. 
 
-  The function uses pattern match to recognize two patterns ('in conbination with' and 'used with') from a sentence. Once such a pattern is recognized, the sentence is parsed as dependency tree by scispacy's nlp_bionlp13cg mdoel which is based on Stanford Dependency Converter. The "combination" or "used" is used as headword to extract its subtree. 
+  The function uses pattern match to recognize two patterns ('in combination with' and 'used with') from a sentence. Once such a pattern is recognized, the sentence is parsed as a dependency tree by scispacy's nlp_bionlp13cg model which is based on Stanford Dependency Converter. The "combination" or "used" is used as a headword to extract its subtree. 
 
   Parameters
   ----------
@@ -368,7 +366,7 @@ def sent_subtree(text):
   
   Examples
   --------
-  Install the necessary packages and pri-trained models
+  Install the necessary packages and pre-trained models
 
   >>> # If using Colab Notebook, use !pip
   $ pip install scispacy
@@ -542,7 +540,7 @@ def is_accelerated_approval_rate(text):
 def is_metastatic(text, disease):
   """Detect if the metastatic disease is mentioned.
 
-  Use keyword matching to detect if the combination of keywords "metastatic" or "unresectable" with disease's name appears in the sentence.
+  Use keyword matching to detect if the combination of keywords "metastatic" or "unresectable" with the disease's name appears in the sentence.
 
   Parameters
   ----------
@@ -577,3 +575,176 @@ def is_metastatic(text, disease):
     return True
   else:
     return False
+
+
+def targeted_therapy_url(url):
+  """Extract the targeted therapies' link from NCI page.
+
+  Use the lxml library to parse the URL link and xpath to find the therapy's link in the "what-targeted-therapies-have-been-approved-for-specific-types-of-cancer" section.
+
+  Parameters
+  ----------
+  url : str
+      An URL link to a targeted therapies fact sheet.
+
+  Returns
+  -------
+  list
+      Return a list of targeted therapies' URL links.
+
+  Examples
+  --------
+  Import the module
+
+  >>> from biomarker_nlp import biomarker_extraction
+  
+  Example
+  
+  >>> url_nci = "https://www.cancer.gov/about-cancer/treatment/types/targeted-therapies/targeted-therapies-fact-sheet"
+  >>> biomarker_extraction.targeted_therapy_url(url = url_nci)[0:5]
+  ['/about-cancer/treatment/drugs/atezolizumab', '/about-cancer/treatment/drugs/nivolumab', '/about-cancer/treatment/drugs/avelumab', '/about-cancer/treatment/drugs/pembrolizumab', '/about-cancer/treatment/drugs/erdafitinib']
+
+  """
+  
+  rp = requests.get(url)
+  page = lxml.html.fromstring(rp.text)
+
+  # get the links of FDA-approved targeted therapies
+  therapy_links = page.xpath("//section[h2[@id = 'what-targeted-therapies-have-been-approved-for-specific-types-of-cancer']]//p//a/@href")
+
+  return therapy_links
+
+
+def targeted_therapy_name(url):
+  """Extract targeted therapy's name on its NCI page.
+
+  Use the lxml library to parse the URL link and xpath to find the therapy's name from the parsed tree structure.
+
+  Parameters
+  ----------
+  url : str
+      An URL link to a targeted therapy's NCI page.
+
+  Returns
+  -------
+  list
+      Return the name of the targeted therapy appearing on its NCI page in a list.
+
+  Examples
+  --------
+  Import the module
+
+  >>> from biomarker_nlp import biomarker_extraction
+  
+  Example
+  
+  >>> url = "https://www.cancer.gov/about-cancer/treatment/drugs/atezolizumab"
+  >>> biomarker_extraction.targeted_therapy_name(url = url)
+  ['Atezolizumab']
+  """
+
+
+  # get the targeted therapy URL and parse it
+  therRp = requests.get(url)
+  therPage = lxml.html.fromstring(therRp.text)
+
+  # extract the therapy's name
+  therapy_name = therPage.xpath("//article/div/h1/text()")
+
+  return therapy_name
+
+
+def therapy_disease(url):
+  """Extract the associated diseases (in bold text) on the therapy's NCI page.
+
+  Extract the associated diseases in bold text on the therapy's NCI page through parsing the URL link. Remove punctuations around the text if there are any.
+
+  Parameters
+  ----------
+  url : str
+      An URL link to a targeted therapy's NCI page.
+
+  Returns
+  -------
+  list
+      Return a list of disease's name. 
+
+  Examples
+  --------
+  Import the module
+
+  >>> from biomarker_nlp import biomarker_extraction
+  
+  Example
+  
+  >>> url = "https://www.cancer.gov/about-cancer/treatment/drugs/atezolizumab"
+  >>> biomarker_extraction.therapy_disease(url = url)
+  ['Breast cancer', 'Urothelial carcinoma', 'Non-small cell lung cancer', 'Hepatocellular carcinoma', 'Melanoma', 'Small cell lung cancer']
+  """
+  
+  # get the targeted therapy URL and parse it
+  therRp = requests.get(url)
+  therPage = lxml.html.fromstring(therRp.text)
+
+  # extract the corresponding diseases (only for bold text, note that there are a few non-bold diseases left)
+  diseases = therPage.xpath("//article//div[h2[contains(text(),'Use in Cancer')]]/ul/li/strong")
+
+  # clear (remove punctuations)
+  punc = '''!()-[]{};:'"\, <>./?@#$%^&*_~'''
+  diseaseList = []
+
+  for disease in diseases:
+      
+    # get the disease in string
+    # remove punctuation at the end of the disease
+    dis = str(disease.text_content())
+    if dis[-1] in punc:
+      dis = dis.replace(dis[-1], "")  
+      
+    # add the diseases to the list
+    diseaseList.append(dis)
+          
+  # remove duplicates
+  diseaseList = list(set(diseaseList))
+
+  return diseaseList
+
+def drug_search_url(url):
+  """Extract the URL link about the search outcome of drug label information. DailyMed URL link (drug information vs multiple research results).
+
+  Extract the URL link of "FDA label information for this drug is available at DailyMed." on the therapy's NCI page. The URL link could be either a DailyMed link to drug label information or a DailyMed link showing multiple search results of the drug. 
+
+  Parameters
+  ----------
+  url : str
+      An URL link to a targeted therapy's NCI page.
+
+  Returns
+  -------
+  list
+      Return a DailyMed URL link in a list.
+
+  Examples
+  --------
+  Import the module
+
+  >>> from biomarker_nlp import biomarker_extraction
+  
+  Example
+  
+  >>> url = "https://www.cancer.gov/about-cancer/treatment/drugs/atezolizumab"
+  >>> biomarker_extraction.drug_search_url(url = url)
+  ['https://dailymed.nlm.nih.gov/dailymed/drugInfo.cfm?setid=6fa682c9-a312-4932-9831-f286908660ee&audience=consumer']
+  >>> url = "https://www.cancer.gov/about-cancer/treatment/drugs/bevacizumab"
+  >>> biomarker_extraction.drug_search_url(url = url)
+  ['https://dailymed.nlm.nih.gov/dailymed/search.cfm?labeltype=all&query=BEVACIZUMAB&pagesize=20&page=1']
+  """
+
+  # get the targeted therapy URL and parse it
+  therRp = requests.get(url)
+  therPage = lxml.html.fromstring(therRp.text)
+
+  # obtain DailyMed link
+  dailyMed = therPage.xpath("//article//div/p/a[text() = 'FDA label information for this drug is available at DailyMed.']/@href")
+
+  return dailyMed
\ No newline at end of file
