@@ -4,11 +4,11 @@
 from biomarker_nlp.negation_negbert import *
 
 def negation_detect(text, modelCue):
-  """Dectect if a sentence contains any negation cues.
+  """Detect if a sentence contains any negation cues.
 
-  This function predicts if a sentence contains any negation words by using a pre-trianed negation dectection model that was pre-trained through Aditya and Suraj's (2020) NegBERT transfer learning program. 
+  This function predicts if a sentence contains any negation words by using a pre-trained negation detection model that was pre-trained through Aditya and Suraj's (2020) NegBERT transfer learning program. 
   Please see the reference link: https://github.com/adityak6798/Transformers-For-Negation-and-Speculation. The model was trained using 'bioscope_abstracts' and 'bioscope_full_papers' corpora. 
-  It was upload to a cloud repository and was freely-available. 
+  It was upload to a cloud repository and was freely available. 
 
   Parameters
   ----------
@@ -34,9 +34,9 @@ def negation_detect(text, modelCue):
   
   Examples
   --------
-  Install the necessary packages, and make sure turn GPU Hardware accelerator on. 
+  Install the necessary packages, and make sure to turn the GPU Hardware accelerator on. 
   
-  >>> If using Colab Notebook, add ! before pip.
+  >>> If using Colab Notebook, use !pip instead pip.
   $ pip install biomarker_nlp
   $ pip install transformers
   $ pip install knockknock==0.1.7
@@ -68,7 +68,7 @@ def negation_detect(text, modelCue):
   dl = mydata.get_cue_dataloader()
   cueIndex = modelCue.predict(dl)
 
-  # check if negation is detected.
+  # check if negation is detected
   if 1 in cueIndex[0][0]:
     return True
   else: return False
@@ -77,10 +77,10 @@ def negation_detect(text, modelCue):
 def negation_scope(text, modelCue, modelScope):
   """Extract the scope of negation in a sentence.
 
-  This function predicts the negation' cues and their scope in a sentence by using two pre-trianed negation models that were pre-trained through Aditya and Suraj's (2020) NegBERT transfer learning program. 
+  This function predicts the negation cues and their scope in a sentence by using two pre-trained negation models that were pre-trained through Aditya and Suraj's (2020) NegBERT transfer learning program. 
   Please see the reference link: https://github.com/adityak6798/Transformers-For-Negation-and-Speculation. The models were trained using 'bioscope_abstracts' and 'bioscope_full_papers' corpora.
-  One of them is used to performed negation cue detection and negation scope resolution. Another one is used to performed negation scope resolution. They were upload to a cloud repository and was freely-available. 
-  This function predicts negation cues first through the negation cue detection model. If any negation cues were predected, it predectes the scope of each negation cue, if there are more than one, through the negation scope resolution model.
+  One of them is used to performed negation cue detection and negation scope resolution. Another one is used to performed negation scope resolution. They were upload to a cloud repository and were freely available. 
+  This function predicts negation cues first through the negation cue detection model. If any negation cues were predicted, it predicts the scope of each negation cue, if there are more than one, through the negation scope resolution model.
 
   Parameters
   ----------
@@ -91,12 +91,12 @@ def negation_scope(text, modelCue, modelScope):
       pre-trained negation cue prediction model
 
   modelScopre : torch model
-      pre-trianed negation scope prediction model
+      pre-trained negation scope prediction model
 
   Returns
   -------
   list
-      a list of negated clauses. Some sentences would contain more than one negation cues, in this case, all of their negated clauses will be extracted. If no negation is found, return an empty list.
+      a list of negated clauses. Some sentences would contain more than one negation cue, in this case, all of their negated clauses will be extracted. If no negation is found, return an empty list.
   
   See Also
   --------
@@ -109,9 +109,9 @@ def negation_scope(text, modelCue, modelScope):
   
   Examples
   --------
-  Install the necessary packages, and make sure turn GPU Hardware accelerator on. 
+  Install the necessary packages, and make sure to turn the GPU Hardware accelerator on. 
   
-  >>> If using Colab Notebook, add ! before pip.
+  >>> If using Colab Notebook, use !pip instead pip.
   $ pip install biomarker_nlp
   $ pip install transformers
   $ pip install knockknock==0.1.7
